
# PyGreen

[![Build Status](https://travis-ci.org/nicolas-van/pygreen.svg?branch=master)](https://travis-ci.org/nicolas-van/pygreen)
[![PyPI](https://img.shields.io/pypi/v/pygreen.svg)](https://pypi.python.org/pypi/pygreen)

A micro web framework/static web site generator.

PyGreen is a simple tool to generate small web sites. The concept is to put all files to serve in a folder and invoke
the [Mako](http://www.makotemplates.org/) template engine on all .html files. The result is quite similar to a classic
PHP application, but with the good features of the Mako templates (like inheritance) and the cool syntax of Python.

[See the documentation here.](https://nicolas-van.github.io/pygreen/)

## License

[See the license file](https://github.com/nicolas-van/pygreen/blob/master/LICENSE.md).

## Contribution

[See the contribution guide](https://github.com/nicolas-van/pygreen/blob/master/CONTRIBUTING.md).
